@@ -9,7 +9,13 @@ module T::Types
     attr_reader :values
 
     def initialize(values)
-      @values = values
+      case values
+      when Hash
+        @values = values
+      else
+        require "set" unless defined?(Set)
+        @values = values.to_set
+      end
     end
 
     def build_type
@@ -25,7 +31,7 @@ module T::Types
     private def subtype_of_single?(other)
       case other
       when Enum
-        (other.values - @values).empty?
+        (@values - other.values).empty?
       else
         false
       end
